summaryrefslogtreecommitdiffstats
path: root/kspread/kspread_doc.cc
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-12-21 14:05:41 -0600
committerTimothy Pearson <[email protected]>2011-12-21 14:05:41 -0600
commit2d6954f69caf63ed5057bd8e1405a65d7d970292 (patch)
tree88e6436b2e81d4e68313f02a9021054252e14cc4 /kspread/kspread_doc.cc
parentf0de9e167e289ab7dc33e57f077c1f04ec7c68c8 (diff)
downloadkoffice-2d6954f69caf63ed5057bd8e1405a65d7d970292.tar.gz
koffice-2d6954f69caf63ed5057bd8e1405a65d7d970292.zip
Rename obsolete tq methods to standard names
Diffstat (limited to 'kspread/kspread_doc.cc')
-rw-r--r--kspread/kspread_doc.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/kspread/kspread_doc.cc b/kspread/kspread_doc.cc
index 8a580ecb..ea698845 100644
--- a/kspread/kspread_doc.cc
+++ b/kspread/kspread_doc.cc
@@ -941,7 +941,7 @@ void Doc::saveOasisDocumentStyles( KoStore* store, KoGenStyles& mainStyles ) con
styles = mainStyles.styles( KoGenStyle::STYLE_PAGELAYOUT );
it = styles.begin();
for ( ; it != styles.end() ; ++it ) {
- (*it).style->writeStyle( stylesWriter, mainStyles, "style:page-tqlayout", (*it).name, "style:page-tqlayout-properties", false /*don't close*/ );
+ (*it).style->writeStyle( stylesWriter, mainStyles, "style:page-layout", (*it).name, "style:page-layout-properties", false /*don't close*/ );
stylesWriter->endElement();
}
@@ -1179,7 +1179,7 @@ bool Doc::loadXML( TQIODevice *, const TQDomDocument& doc )
return false;
}
//Backwards compatibility with older versions for paper tqlayout
if ( d->syntaxVersion < 1 )
{
TQDomElement paper = spread.namedItem( "paper" ).toElement();
@@ -1549,7 +1549,7 @@ void Doc::setZoomAndResolution( int zoom, int dpiX, int dpiY )
void Doc::newZoomAndResolution( bool updateViews, bool /*forPrint*/ )
{
-/* tqlayout();
+/* layout();
updateAllFrames();*/
if ( updateViews )
{
@@ -1179,7 +1179,7 @@ bool Doc::loadXML( TQIODevice *, const TQDomDocument& doc )
return false;
}
- //Backwards compatibility with older versions for paper tqlayout
+ //Backwards compatibility with older versions for paper layout
if ( d->syntaxVersion < 1 )
{